@@ -2,11 +2,21 @@ package FBP::Project;
 
 use Mouse;
 
-our $VERSION = '0.29';
+our $VERSION = '0.30';
 
 extends 'FBP::Object';
 with    'FBP::Children';
 
+has name => (
+	is  => 'ro',
+	isa => 'Str',
+);
+
+has relative_path => (
+	is  => 'ro',
+	isa => 'Bool',
+);
+
 has internationalize => (
 	is  => 'ro',
 	isa => 'Bool',
@@ -21,10 +31,18 @@ no Mouse;
 ######################################################################
 # Convenience Methods
 
+sub forms {
+	return grep {
+		Params::Util::_INSTANCE($_, 'FBP::Window')
+		and
+		$_->does('FBP::Form')
+	} @{$_[0]->children};
+}
+
 sub dialogs {
 	return grep { 
 		Params::Util::_INSTANCE($_, 'FBP::Dialog')
-	} @{$_[0]->children}
+	} @{$_[0]->children};
 }
 
 1;
